Files — Flag Slurper 0.4 documentation

# Files

Flag slurper contains a database of files found on competitior machines. This is normally populated by the AutoPWN functionality. All file commands require that a Project is set.

## Usage

The main command you’ll use is listing all files in the database.

    flag-slurper files ls

The `ls` command can be filtered by team number (`-t TEAM`), file name (`-n NAME`), and/or service name (`-s SERVICE`).

Once you find a file you want to see, you can use the `show` command. This will display metadata on the file and will then open the file in your text editor if it is a text file.

    flag-slurper files show 1

You may also save the file directly from the database to the given file path.

    flag-slurper files get 1 ~/team1_shadow

If you don’t want to keep a file around any more, you can remove it.

    flag-slurper files rm 1

## Example